icsemantic.catalog.config

Package platecom :: Package ontocatalog :: Module config |
[hide private]
[frames] | no frames]

# Module config

source code

Global constants for OntoCatalog.

Variables | [hide private]
| GLOBALS = `globals()`
| HAS_PLONE3 = `False`
| PROJECTNAME = `"icsemantic.catalog"`
| PACKAGE = `icsemantic.catalog`
| PACKAGENAME = `"icsemantic.catalog"`
| DEPENDENCIES = `['LinguaPlone', 'pluggablecatalog', 'platecom.l`...``
| SYNONYM_IDX = `'SearchableSynonymousText'`
| TRANSLATION_IDX = `'SearchableTranslatedText'`
| RELATED_IDX = `'SearchableRelatedText'`

Variables Details | [hide private]

  ### DEPENDENCIES Value:
      ['LinguaPlone', 'pluggablecatalog', 'icsemantic.langfallback', 'platecom.ont
      oplone']